@@ -34,14 +34,14 @@ class K3SController:
         if status_code>299:
             if isinstance(info['detail'], str):
                 return_code = return_codes['OTHER_CODE']
-                error_info = info['detail']
+                error_traceback = info['detail']
             else:
                 return_code = info['detail']['return_code']
-                error_info = info['detail']['error_info']
-            raise error_factory.make(return_code)(error_info)
+                error_traceback = info['detail']['error_traceback']
+            raise error_factory.make(return_code)(error_traceback)
 
     @exception_class_dec(max_try=1)
-    def check_connection(self, timeout=30):
+    def check_connection(self, timeout=3):
         response=requests.get(f'{self.url}', headers=self.header, timeout=timeout)
         info = json.loads(response.text)
         self._check_error(response.status_code, info)
